/*  Copyright (C) MOXA Inc. All rights reserved.

    This software is distributed under the terms of the
    MOXA License.  See the file COPYING-MOXA for details.
*/
/*
	Get UART Mode
	
	param:
		(in)int index :	Port index (0,1)		
				
	Return value:
		int:		0 : RS232 Mode
					1 : RS485-2W Mode
					2 : RS422 Mode
					3 : RS485-4W Mode
*/
int uart_getmode(int index);

/*
	Set UART Mode
	
	param:
		(in)int index  :	Port index		
		(in)int mode   :	Port mode		
				
	Return value:
		int:			Current Mode. 
*/
int uart_setmode(int index,int mode);

/*
	Initialize Digitial I/O
	
	param:
		None  :		
				
	Return value:
		HANDLE:			return digital I/O handle
*/
unsigned int mxdio_open();

/*
	get digital input
	
	param:
		(in)HANDLE hDIO  :	Handle of digital I/O		
				
	Return value:
		int:			return digital input data 
*/
int mxdio_get_din(unsigned int fd, unsigned int port_no);

/*
	set digital output
	
	param:
		(in)HANDLE hDIO  :	Handle of digital I/O		
		(in)int index	 :	index of digital output bit		
		(in)int data	 :	digital output data (0,1) 
	Return value:
		BOOL:			TRUE indicates success, FALSE indicates failure.
*/
int mxdio_set_dout(unsigned int fd, unsigned int port_no, int data);

/*
	get digital output
	
	param:
		(in)HANDLE hDIO  :	Handle of digital I/O		
		(in)int index	 :	index of digital output			
	Return value:
		int:			return digital output data 
*/
int mxdio_get_dout(unsigned int fd, unsigned int port_no);

/*
	close digital I/O
	
	param:
		(in)HANDLE hDIO  :	Handle of digital I/O		
				
	Return value:
		BOOL:			TRUE indicates success, FALSE indicates failure. 
*/
void mxdio_close(unsigned int fd);

